<?php

// Set options array
function purplepastels_all_theme_options() {
	$all_theme_options = array(
		'accordion' => array(
			'label' => __(' Collapsing sub-menus', 'purplepastels'),
			'type' => 'radio',
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Enabled', 'purplepastels' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'Disabled', 'purplepastels' )
				)
			)
		),
		'pt_width' => array(
			'type' => 'text',
			'label' => __('Featured image width', 'purplepastels'),
			'default' => '150',
			'size' => 3,
			'maxlength' => 3,
			'numeric' => 1
		),
		'pt_height' => array(
			'type' => 'text',
			'label' => __('Featured image height', 'purplepastels'),
			'default' => '150',
			'size' => 3,
			'maxlength' => 3,
			'numeric' => 1
		),
		'pt_crop' => array(
			'type' => 'radio',
			'label' => __('Featured image cropping', 'purplepastels'),
			'default' => 'soft',
			'choices' => array(
				'1' => array(
					'value' => 'soft',
					'label' => __( 'Soft (proportional)', 'purplepastels' )
				),
				'2' => array(
					'value' => 'hard',
					'label' => __( 'Hard (fixed)', 'purplepastels' )
				)
			)
		),
		'custom_excerpt' => array(
			'type' => 'text',
			'label' => __('Post excerpt length (in words)', 'purplepastels'),
			'default' => '100',
			'size' => 3,
			'maxlength' => 3,
			'numeric' => 1
		),
		'display_subpages' => array(
			'type' => 'radio',
			'label' => __('Pages in this section list', 'purplepastels'),
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Display', 'purplepastels' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'Hide', 'purplepastels' )
				)
			)
		),
		'display_kses' => array(
			'type' => 'radio',
			'label' => __('Allowed comment tags', 'purplepastels'),
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Display', 'purplepastels' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'Hide', 'purplepastels' )
				)
			)
		),
		'display_postlist' => array(
			'type' => 'radio',
			'label' => __('Post numbers (a - b of x entries)', 'purplepastels'),
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Display', 'purplepastels' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'Hide', 'purplepastels' )
				)
			)
		),
		'display_widget_titles' => array(
			'type' => 'radio',
			'label' => __('Widget titles ', 'purplepastels'),
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Display', 'purplepastels' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'Hide', 'purplepastels' )
				)
			)
		)
	);
	return apply_filters( 'purplepastels_default_theme_options', $all_theme_options );
}

// White list theme options
function theme_options_init() {
	register_setting( 'theme_options', 'purplepastels_theme_options', 'pp_theme_options_validate' );
}
add_action( 'admin_init', 'theme_options_init' );

// Add theme options page
function theme_options_add_page() {
	$theme_page = add_theme_page( __( 'Theme Options', 'purplepastels' ), __( 'Theme Options', 'purplepastels' ), 'edit_theme_options', 'pp_theme_options', 'pp_theme_options_do_page' );
	if ( $theme_page ) add_action( 'load-' . $theme_page, 'pp_contextual_help' );
}
add_action('admin_menu', 'theme_options_add_page');

function pp_theme_options_enqueue_style() {
	wp_enqueue_style('purple_pastels_options_style', get_template_directory_uri() . '/library/theme-options.css', '', false, 'screen');
	if ( file_exists( get_template_directory() . '/theme-options-custom.css' ) )
		wp_enqueue_style('purple_pastels_options_custom_style',get_template_directory_uri() . '/theme-options-custom.css', '', false, 'screen');
}
add_action('admin_print_styles-appearance_page_pp_theme_options', 'pp_theme_options_enqueue_style');


// Add theme help links
function pp_contextual_help() {
	$screen = get_current_screen();
	$help = '<ul class="contextual-links">';
	$help .= '<li><a href="http://quirm.net/forum/forum.php?id=15">' .__( 'Purple Pastels support on Quirm.net', 'purplepastels') . '</a></li>';
	$help .= '<li><a href="http://wordpress.org/tags/purple-pastels">' .__( 'Purple Pastels support on wordress.org', 'purplepastels') . '</a></li>';
	$help .= '</ul>';
	$screen->add_help_tab( array(
		'id'      => 'theme-support',
		'title'   => __( 'Theme Support', 'purplepastel' ),
		'content' => $help,
	) );
}

// Theme options form
function pp_theme_options_do_page() {
	if ( ! isset( $_REQUEST['updated'] ) ) $_REQUEST['updated'] = false;
	?>

	<div class="wrap">
	<?php screen_icon(); echo '<h2>'.  __( ' Theme Options', 'purplepastels') . "</h2>"; ?>

	<?php if ( false !== $_REQUEST['updated'] ) : ?>
	<div class="updated fade"><p><strong><?php _e( 'Your theme options have been saved', 'purplepastels'); ?></strong></p></div>
	<?php endif;?>

	<?php include_once 'donate.php';?>

	<form method="post" action="options.php" id="purplepastels_theme_options"><div>
	<?php settings_fields( 'theme_options' ); ?>
	<?php
	$stored_options = get_option('purplepastels_theme_options');
	$all_theme_options = purplepastels_all_theme_options();
	?>

	<?php $option_name = 'accordion';
	 pp_options_do_radio( $option_name, $all_theme_options[$option_name], $stored_options );?>

	<fieldset class="pt-size">
	<legend><?php _e('Post thumbnails', 'purplepastels'); ?></legend>
	<?php $option_name = 'pt_width';
	pp_options_do_text( $all_theme_options[$option_name], $stored_options, $option_name);?><br />
	<?php $option_name = 'pt_height';
	pp_options_do_text( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<?php $option_name = 'pt_crop';
	 pp_options_do_radio( $option_name, $all_theme_options[$option_name], $stored_options );?>

	<fieldset>
	<legend><?php _e('Post excerpt length', 'purplepastels'); ?></legend>
	<?php $option_name = 'custom_excerpt';
	pp_options_do_text( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<?php $option_name = 'display_subpages';
	 pp_options_do_radio( $option_name, $all_theme_options[$option_name], $stored_options );?>

	<?php $option_name = 'display_kses';
	 pp_options_do_radio( $option_name, $all_theme_options[$option_name], $stored_options );?>

	<?php $option_name = 'display_postlist';
	 pp_options_do_radio( $option_name, $all_theme_options[$option_name], $stored_options );?>

	<?php $option_name = 'display_widget_titles';
	 pp_options_do_radio( $option_name, $all_theme_options[$option_name], $stored_options );?>

	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Update Theme', 'purplepastels') ?>" /></p>

	</div></form>
</div>
	<?php
}

// Radio button display
function pp_options_do_radio($option_name, $option, $stored_options ) {
	if ( !isset( $stored_options[$option_name] ) ) $stored_options[$option_name] = $option['default'];?>

	<fieldset>
	<legend><?php echo esc_attr( $option['label'] ); ?></legend>
	<?php foreach ( $option['choices'] as $option ) {?>
		<label class="description radio" for="<?php echo $option_name;?>_<?php echo esc_attr( $option['value'] ); ?>"><input type="radio" id="<?php echo $option_name;?>_<?php echo esc_attr( $option['value'] ); ?>" name="purplepastels_theme_options[<?php echo $option_name;?>]" value="<?php echo esc_attr( $option['value'] ); ?>" <?php checked( $stored_options[$option_name] , $option['value'] ); ?> /> <?php echo $option['label']; ?></label><?php
	}?>
	</fieldset>
	<?php
}


// Text input display
function pp_options_do_text($setting, $stored_options, $name) {
	if( isset( $stored_options[$name] ) ) {
		if( $setting['numeric'] == 1 ) {
			if( ctype_digit( $stored_options[$name] ) ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
		else {
			if( $stored_options[$name] != '' ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
	}
	else $current_value = $setting['default'];
	?>
	<label class="description text" for="<?php echo $name;?>"><?php echo $setting['label'];?></label> <input type="text" id="<?php echo $name;?>" name="purplepastels_theme_options[<?php echo $name;?>]" maxlength="<?php echo $setting['maxlength'];?>" value="<?php echo $current_value;?>" />
	<?php
}

// Sanitize and validate inputs
function pp_theme_options_validate( $input ) {
	$new_input = array();
	$all_theme_options = purplepastels_all_theme_options();
	$theme_option_names = array_keys($all_theme_options);

	foreach($theme_option_names as $theme_option_name) {
		$option_type = $theme_option_name['type'];
		switch ($option_type) {

			case 'radio':
			if( $all_theme_options[$theme_option_name]['default'] == 'yes' ) $new_input[$theme_option_name] = ( $input[$theme_option_name] == 'yes' ? 'yes' : 'no' );

			case 'text':
			$new_input[$theme_option_name] = wp_filter_nohtml_kses( $input[$theme_option_name] );
			break;

			default:
			$new_input[$theme_option_name] = $input[$theme_option_name];
		}
		if( !isset( $input[$theme_option_name] ) ) $new_input[$theme_option_name] = $theme_option_name['default'];
	}
	return $new_input;
}

/* THEME CUSTOMIZER */

// Add theme options to Customizer
function purplepastels_customize_register($wp_customize) {
	$all_purplepastels_theme_options = purplepastels_all_theme_options();

	 //Add section
	$wp_customize->add_section( 'purplepastels_theme_options', array(
		'title' => __( 'Theme Options', 'purplepastels' ),
		'priority'       => 200,
	) );

	foreach( $all_purplepastels_theme_options as $option_key => $option_values ) {
		// Add settings
		$option_name = 'purplepastels_theme_options[' . $option_key . ']';
		$wp_customize->add_setting( $option_name, array(
			'default' => $option_values['default'],
			'type'  => 'option',
			'capability' => 'edit_theme_options',
		) );
		// Add radio controls
		if( $option_values['type'] == 'radio' ) {
			$choices = array();
			foreach( $option_values['choices'] as $option ) {
				$ckey = $option['value'];
				$cvalue = $option['label'];
				$choices[ $ckey ] = $cvalue;
			}
			$wp_customize->add_control( $option_name, array(
				'label' => $option_values['label'],
				'section' => 'purplepastels_theme_options',
				'settings' => $option_name,
				'type' => 'radio',
				'choices' => $choices,
			) );
		}
		// Add text controls
		if( $option_values['type'] == 'text' ) {
			$wp_customize->add_control( $option_name, array(
				'label' => $option_values['label'],
				'section' => 'purplepastels_theme_options',
				'settings' => $option_name,
				'type' => 'text',
			) );
		}
	}
	if ( $wp_customize->is_preview() ) add_action('customize_controls_print_styles', 'pp_theme_options_enqueue_style');
}
add_action( 'customize_register', 'purplepastels_customize_register' );
